@@ -761,7 +761,7 @@ build_tab_label (EphyNotebook *nb,
   g_signal_connect_object (embed, "notify::title",
                            G_CALLBACK (title_changed_cb), nb, 0);
 
-  g_object_bind_property (view, "title", tab_label, "label-text", G_BINDING_DEFAULT);
+  g_object_bind_property (embed, "title", tab_label, "label-text", G_BINDING_DEFAULT);
   g_object_bind_property (view, "display-address", tab_label, "label-uri", G_BINDING_DEFAULT);
   g_object_bind_property (view, "icon", tab_label, "icon-buf", G_BINDING_DEFAULT);
   g_object_bind_property (view, "is-loading", tab_label, "spinning", G_BINDING_DEFAULT);
